"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileTabs = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("@liqvid/utils/react");
const codemirror_1 = require("@lqv/codemirror");
const react_2 = require("react");
const zustand_1 = require("zustand");
const store_1 = require("../store.cjs");
const utils_1 = require("../utils.cjs");
const selector = (state) => [state.activeGroup, state.groups[state.activeGroup]?.activeFile];
/**
 * File selector component.
 */
function FileTabs() {
    const store = (0, store_1.useBoothStore)();
    const [activeGroup, activeFilename] = (0, zustand_1.useStore)(store, selector);
    const group = store.getState().groups[activeGroup];
    const { recorder } = store.getState();
    const events = (0, react_2.useMemo)(() => (0, react_1.onClick)(e => {
        // record event
        // @ts-expect-error Manager needs to be changed from protected to public
        if (recorder?.manager?.active) {
            recorder.capture(undefined, codemirror_1.selectCmd + e.currentTarget.textContent);
        }
        // set state
        store.setState(state => ({
            groups: {
                ...state.groups,
                [state.activeGroup]: {
                    ...(state.groups[state.activeGroup]),
                    activeFile: e.currentTarget.textContent.trim()
                }
            }
        }));
    }), [recorder]);
    // set class
    (0, react_2.useEffect)(() => {
        store.setState(prev => ({ classNames: prev.classNames.concat("multifile") }));
    }, []);
    if (!group)
        return null;
    return ((0, jsx_runtime_1.jsx)("div", { className: "lqv-file-tabs", role: "tablist", children: group.files.map(({ filename }) => ((0, jsx_runtime_1.jsx)("button", { className: `lqv-filetype-${getFileType(filename)}`, id: utils_1.ids.fileTab({ filename, group: activeGroup }), "aria-controls": utils_1.ids.editorPanel({ filename, group: activeGroup }), "aria-selected": activeFilename === filename, role: "tab", ...events, children: filename }, filename))) }));
}
exports.FileTabs = FileTabs;
/**
 * Get file extension.
 * @param filename Name of file.
 * @returns File extension.
 */
function getFileType(filename) {
    return filename.slice(filename.lastIndexOf(".") + 1);
}
