import { jsx as _jsx } from "react/jsx-runtime.js";
import { keymap } from "@codemirror/view";
import { passThrough } from "@lqv/codemirror/extensions";
import { CodeRecording } from "@lqv/codemirror/recording";
import { useKeymap } from "@liqvid/keymap/react";
import { useEffect, useMemo } from "react";
import { recording } from "../extensions.mjs";
import { useBoothStore } from "../store.mjs";
import { Editor } from "./Editor.mjs";
/** Recording editor. */
export const Record = (props) => {
    const { captureKeys = {
        "Mod-Enter": "run",
        "Mod-K": "clear",
        "Mod-L": "clear"
    }, extensions = [], group = "default", passKeys = ["Mod-Alt-2", "Mod-Alt-3", "Mod-Alt-4"], ...attrs } = props;
    const store = useBoothStore();
    const lqvKeymap = useKeymap();
    const newExtensions = useMemo(() => lqvKeymap ? [
        keymap.of(passThrough(lqvKeymap, passKeys)),
        ...extensions
    ] : [], [passKeys]);
    // attach recording extensions --- this has to be done this way because
    // the `shortcuts` Compartment will abort further handling of the sequence
    useEffect(() => {
        const { view } = store.getState().groups[group].files.find(file => file.filename === props.filename);
        view.dispatch({
            effects: recording.reconfigure([
                recording.get(view.state),
                [CodeRecording.recorder.extension(captureKeys)]
            ])
        });
    }, []);
    return (_jsx(Editor, { content: props.content, extensions: newExtensions, ...attrs }));
};
