import { jsx as _jsx } from "react/jsx-runtime.js";
import { clamp } from "@liqvid/utils/misc";
import { onDrag } from "@liqvid/utils/react";
import { useMemo, useRef } from "react";
/**
 * Component for adjusting the vertical editor/console split.
 */
export const Resize = ({ dir = "ew" }) => {
    const ref = useRef();
    /* event handlers */
    const resizeEvents = useMemo(() => {
        let container;
        return onDrag((e, { x, y }) => {
            const rect = container.getBoundingClientRect();
            if (dir === "ew") {
                container.style.setProperty("--split", clamp(0.25, (x - rect.left) / rect.width, 0.75) * 100 + "%");
            }
            else if (dir === "ns") {
                container.style.setProperty("--v-split", clamp(0.05, (rect.bottom - y) / rect.height, 0.75) * 100 + "%");
            }
        }, () => {
            container = ref.current.closest(".lqv-codebooth");
            container.classList.add("dragging");
        }, () => {
            container.classList.remove("dragging");
        });
    }, []);
    return (_jsx("div", { ...resizeEvents, ref: ref, className: `ui-resizable-handle ui-resizable-${dir}`, style: { zIndex: 90 } }));
};
